===============
Release History
===============

v0.0.4 (2021-01-16)
===================

This version adds bidsonym to PyPi.

v0.0.3 (2021-01-16)
===================

This release mainly consists of various bug fixes and minor new features. 
Bug fixes mainly addressed problems related to how sessions and corresponding were handled. 
New features in particular refer to reorganizing the outcomes into data (and if present session) 
specific directories and stable graphics generation.  

v0.0.2 (2020-08-12)
===================

Initial release draft to enable further work on versioning.

v0.0.1 (2020-08-12)
===================

Initial release draft to enable further work on versioning.